@@ -3,7 +3,8 @@
 /**
  * @file classes/file/JournalFileManager.inc.php
  *
- * Copyright (c) 2003-2009 John Willinsky
+ * Copyright (c) 2014-2016 Simon Fraser University Library
+ * Copyright (c) 2003-2016 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class JournalFileManager
@@ -12,31 +13,28 @@
  * @brief Class defining operations for private journal file management.
  */
 
-// $Id$
+import('lib.pkp.classes.file.BaseSubmissionFileManager');
 
-
-import('file.FileManager');
-
-class JournalFileManager extends FileManager {
-
-	/** @var string the path to location of the files */
-	var $filesDir;
-
-	/** @var int the ID of the associated journal */
-	var $journalId;
+class JournalFileManager extends BaseSubmissionFileManager {
 
 	/** @var Journal the associated article */
 	var $journal;
 
 	/**
 	 * Constructor.
-	 * Create a manager for handling journal file uploads.
 	 * @param $journalId int
+	 * @param $articleId int
 	 */
-	function JournalFileManager(&$journal) {
-		$this->journalId = $journal->getJournalId();
-		$this->journal =& $journal;
-		$this->filesDir = Config::getVar('files', 'files_dir') . '/journals/' . $this->journalId . '/';
+	function JournalFileManager($journalId, $articleId) {
+		parent::BaseSubmissionFileManager($journalId, $articleId);
+	}
+
+	/**
+	 * Get the base path for file storage
+	 * @return string
+	 */
+	function getBasePath() {
+		return parent::getBasePath() . '/journals/' . $this->contextId . '/';
 	}
 
 	function uploadFile($fileName, $destFileName) {
