@@ -1,13 +1,14 @@
 <?php
 
 /**
- * @defgroup pages_oai
+ * @defgroup pages_oai OAI Pages
  */
  
 /**
  * @file pages/oai/index.php
  *
- * Copyright (c) 2003-2009 John Willinsky
+ * Copyright (c) 2014-2016 Simon Fraser University Library
+ * Copyright (c) 2003-2016 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @ingroup pages_oai
@@ -15,11 +16,11 @@
  *
  */
 
-// $Id$
-
-
-define('HANDLER_CLASS', 'OAIHandler');
-
-import('pages.oai.OAIHandler');
+switch ($op) {
+	case 'index':
+		define('HANDLER_CLASS', 'OAIHandler');
+		import('pages.oai.OAIHandler');
+		break;
+}
 
 ?>
