@@ -1,13 +1,14 @@
 <?php
 
 /**
- * @defgroup pages_payment
+ * @defgroup pages_payment Payment Pages
  */
  
 /**
  * @file pages/payment/index.php
  *
- * Copyright (c) 2003-2009 John Willinsky
+ * Copyright (c) 2014-2016 Simon Fraser University Library
+ * Copyright (c) 2003-2016 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @ingroup pages_payment
@@ -15,11 +16,11 @@
  * sites/systems.
  */
 
-// $Id$
-
-
-define('HANDLER_CLASS', 'PaymentHandler');
-
-import('pages.payment.PaymentHandler');
+switch ($op) {
+	case 'plugin':
+		define('HANDLER_CLASS', 'PaymentHandler');
+		import('pages.payment.PaymentHandler');
+		break;
+}
 
 ?>
