@@ -1,9 +1,10 @@
 <?php
 
 /**
- * @file CbeCitationPlugin.inc.php
+ * @file plugins/citationFormats/cbe/CbeCitationPlugin.inc.php
  *
- * Copyright (c) 2003-2009 John Willinsky
+ * Copyright (c) 2014-2016 Simon Fraser University Library
+ * Copyright (c) 2003-2016 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class CbeCitationPlugin
@@ -12,9 +13,6 @@
  * @brief CBE citation format plugin
  */
 
-// $Id$
-
-
 import('classes.plugins.CitationPlugin');
 
 class CbeCitationPlugin extends CitationPlugin {
@@ -34,15 +32,15 @@ class CbeCitationPlugin extends CitationPlugin {
 	}
 
 	function getDisplayName() {
-		return Locale::translate('plugins.citationFormats.cbe.displayName');
+		return __('plugins.citationFormats.cbe.displayName');
 	}
 
 	function getCitationFormatName() {
-		return Locale::translate('plugins.citationFormats.cbe.citationFormatName');
+		return __('plugins.citationFormats.cbe.citationFormatName');
 	}
 
 	function getDescription() {
-		return Locale::translate('plugins.citationFormats.cbe.description');
+		return __('plugins.citationFormats.cbe.description');
 	}
 
 }
