@@ -1,9 +1,10 @@
 <?php
 
 /**
- * @file MlaCitationPlugin.inc.php
+ * @file plugins/citationFormats/mla/MlaCitationPlugin.inc.php
  *
- * Copyright (c) 2003-2009 John Willinsky
+ * Copyright (c) 2014-2016 Simon Fraser University Library
+ * Copyright (c) 2003-2016 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class MlaCitationPlugin
@@ -12,9 +13,6 @@
  * @brief MLA citation format plugin
  */
 
-// $Id$
-
-
 import('classes.plugins.CitationPlugin');
 
 class MlaCitationPlugin extends CitationPlugin {
@@ -34,15 +32,15 @@ class MlaCitationPlugin extends CitationPlugin {
 	}
 
 	function getDisplayName() {
-		return Locale::translate('plugins.citationFormats.mla.displayName');
+		return __('plugins.citationFormats.mla.displayName');
 	}
 
 	function getCitationFormatName() {
-		return Locale::translate('plugins.citationFormats.mla.citationFormatName');
+		return __('plugins.citationFormats.mla.citationFormatName');
 	}
 
 	function getDescription() {
-		return Locale::translate('plugins.citationFormats.mla.description');
+		return __('plugins.citationFormats.mla.description');
 	}
 
 }
