@@ -1,9 +1,10 @@
 <?php
 
 /**
- * @file RefManCitationPlugin.inc.php
+ * @file plugins/citationFormats/refMan/RefManCitationPlugin.inc.php
  *
- * Copyright (c) 2003-2009 John Willinsky
+ * Copyright (c) 2014-2016 Simon Fraser University Library
+ * Copyright (c) 2003-2016 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class RefManCitationPlugin
@@ -12,12 +13,9 @@
  * @brief Reference Manager citation format plugin
  */
 
-// $Id$
+import('classes.plugins.DownloadableCitationPlugin');
 
-
-import('classes.plugins.CitationPlugin');
-
-class RefManCitationPlugin extends CitationPlugin {
+class RefManCitationPlugin extends DownloadableCitationPlugin {
 	function register($category, $path) {
 		$success = parent::register($category, $path);
 		$this->addLocaleData();
@@ -34,26 +32,27 @@ class RefManCitationPlugin extends CitationPlugin {
 	}
 
 	function getDisplayName() {
-		return Locale::translate('plugins.citationFormats.refMan.displayName');
+		return __('plugins.citationFormats.refMan.displayName');
 	}
 
 	function getCitationFormatName() {
-		return Locale::translate('plugins.citationFormats.refMan.citationFormatName');
+		return __('plugins.citationFormats.refMan.citationFormatName');
 	}
 
 	function getDescription() {
-		return Locale::translate('plugins.citationFormats.refMan.description');
+		return __('plugins.citationFormats.refMan.description');
 	}
 
 	/**
-	 * Return a custom-formatted citation.
+	 * Set the headers for a downloadable citation.
+	 *
 	 * @param $article object
 	 * @param $issue object
+	 * @param $journal object
 	 */
-	function cite(&$article, &$issue) {
-		header('Content-Disposition: attachment; filename="' . $article->getArticleId() . '-refMan.ris"');
-		$templateMgr =& TemplateManager::getManager();
-		$templateMgr->display($this->getTemplatePath() . '/citation.tpl', 'application/x-Research-Info-Systems');
+	function setHeaders($article, $issue, $journal) {
+		header('Content-Disposition: attachment; filename="' . $article->getId() . '-refMan.ris"');
+		header('Content-Type: application/x-Research-Info-Systems');
 	}
 }
 
